@@ -22,29 +22,17 @@ from cached_property import cached_property
 from bluepysnap.config import Config
 from bluepysnap.node_sets import NodeSets
 from bluepysnap.nodes import Nodes
-from bluepysnap.edges import EdgeStorage
-from bluepysnap.exceptions import BluepySnapError
+from bluepysnap.edges import Edges
 
 
-def _collect_populations(partial_config, cls):
-    result = {}
-    for file_config in partial_config:
-        storage = cls(file_config)
-        for population in storage.population_names:
-            if population in result:
-                raise BluepySnapError("Duplicated population: '%s'" % population)
-            result[population] = storage.population(population)
-    return result
-
-
-class Circuit(object):
+class Circuit:
     """Access to circuit data."""
 
     def __init__(self, config):
         """Initializes a circuit object from a SONATA config file.
 
         Args:
-            config (str): Path to a SONATA config file.
+            config (str/dict): Path to a SONATA config file or sonata config dict.
 
         Returns:
             Circuit: A Circuit object.
@@ -65,13 +53,10 @@ class Circuit(object):
 
     @cached_property
     def nodes(self):
-        """Access to node population(s). See :py:class:`~bluepysnap.nodes.NodePopulation`."""
+        """Access to node population(s). See :py:class:`~bluepysnap.nodes.Nodes`."""
         return Nodes(self)
 
     @cached_property
     def edges(self):
-        """Access to edge population(s). See :py:class:`~bluepysnap.edges.EdgePopulation`."""
-        return _collect_populations(
-            self._config['networks']['edges'],
-            lambda cfg: EdgeStorage(cfg, self)
-        )
+        """Access to edge population(s). See :py:class:`~bluepysnap.edges.Edges`."""
+        return Edges(self)
