@@ -18,6 +18,7 @@
 """Edge population access."""
 import inspect
 from collections.abc import Mapping
+from copy import deepcopy
 
 import libsonata
 import numpy as np
@@ -29,7 +30,7 @@ from bluepysnap import query
 from bluepysnap.network import NetworkObject
 from bluepysnap.exceptions import BluepySnapError
 from bluepysnap.circuit_ids import CircuitEdgeId, CircuitEdgeIds, CircuitNodeId, CircuitNodeIds
-from bluepysnap.sonata_constants import DYNAMICS_PREFIX, Edge, ConstContainer
+from bluepysnap.sonata_constants import DEFAULT_EDGE_TYPE, DYNAMICS_PREFIX, Edge, ConstContainer
 from bluepysnap import utils
 from bluepysnap.utils import Deprecate, IDS_DTYPE
 from bluepysnap._doctools import AbstractDocSubstitutionMeta
@@ -77,11 +78,11 @@ class Edges(NetworkObject, metaclass=AbstractDocSubstitutionMeta,
         if isinstance(group, CircuitEdgeIds):
             diff = np.setdiff1d(group.get_populations(unique=True), self.population_names)
             if diff.size != 0:
-                raise BluepySnapError("Population {} does not exist in the circuit.".format(diff))
+                raise BluepySnapError(f"Population {diff} does not exist in the circuit.")
         fun = lambda x: (x.ids(group), x.name)
         return self._get_ids_from_pop(fun, CircuitEdgeIds, sample=sample, limit=limit)
 
-    def get(self, edge_ids=None, properties=None):   # pylint: disable=arguments-differ
+    def get(self, edge_ids=None, properties=None):   # pylint: disable=arguments-renamed
         """Edge properties as pandas DataFrame.
 
         Args:
@@ -101,15 +102,19 @@ class Edges(NetworkObject, metaclass=AbstractDocSubstitutionMeta,
         if edge_ids is None:
             raise BluepySnapError("You need to set edge_ids in get.")
         if properties is None:
-            Deprecate.warn("Returning ids with get/properties will be removed in 1.0.0."
-                           "Please use Edges.ids() instead.")
+            Deprecate.warn(
+                "Returning ids with get/properties is deprecated and will be removed in 1.0.0. "
+                "Please use Edges.ids instead."
+            )
             return edge_ids
         return super().get(edge_ids, properties)
 
     def properties(self, edge_ids, properties):
         """Doc is overridden below."""
-        Deprecate.warn("Edges.properties function will be deprecated in 1.0.0. Please use "
-                       "Edges.get instead.")
+        Deprecate.warn(
+            "Edges.properties function is deprecated and will be removed in 1.0.0. "
+            "Please use Edges.get instead."
+        )
         return self.get(edge_ids, properties)
 
     properties.__doc__ = get.__doc__
@@ -303,7 +308,8 @@ class EdgeStorage:
             EdgeStorage: A EdgeStorage object.
         """
         self._h5_filepath = config['edges_file']
-        self._csv_filepath = config['edge_types_file']
+        self._csv_filepath = config.get('edge_types_file')
+        self._populations_config = config.get('populations', {})
         self._circuit = circuit
         self._populations = {}
 
@@ -335,7 +341,11 @@ class EdgeStorage:
     def population(self, population_name):
         """Access the different populations from the storage."""
         if population_name not in self._populations:
-            self._populations[population_name] = EdgePopulation(self, population_name)
+            population_config = self._populations_config.get(population_name, {})
+
+            self._populations[population_name] = EdgePopulation(
+                self, population_name, population_config)
+
         return self._populations[population_name]
 
 
@@ -356,16 +366,18 @@ def _estimate_range_size(func, node_ids, n=3):
 class EdgePopulation:
     """Edge population access."""
 
-    def __init__(self, edge_storage, population_name):
+    def __init__(self, edge_storage, population_name, population_config=None):
         """Initializes a EdgePopulation object from a EdgeStorage and a population name.
 
         Args:
             edge_storage (EdgeStorage): the edge storage containing the edge population
             population_name (str): the name of the edge population
+            population_config (dict): the config for the population
 
         Returns:
             EdgePopulation: An EdgePopulation object.
         """
+        self._config = population_config or {}
         self._edge_storage = edge_storage
         self.name = population_name
 
@@ -390,6 +402,18 @@ class EdgePopulation:
         result = self._edge_storage.circuit.nodes[population_name]
         return result
 
+    @cached_property
+    def config(self):
+        """Population config dictionary combined with the components dictionary."""
+        components = deepcopy(self._edge_storage.circuit.config.get('components', {}))
+        components.update(self._config)
+        return components
+
+    @property
+    def type(self):
+        """Population type."""
+        return self.config.get('type', DEFAULT_EDGE_TYPE)
+
     @cached_property
     def source(self):
         """Source NodePopulation."""
@@ -462,15 +486,17 @@ class EdgePopulation:
             result = self._population.get_dynamics_attribute(
                 prop.split(DYNAMICS_PREFIX)[1], selection)
         else:
-            raise BluepySnapError("No such property: %s" % prop)
+            raise BluepySnapError(f"No such property: {prop}")
         return result
 
     def _get(self, selection, properties=None):
         """Get an array of edge IDs or DataFrame with edge properties."""
         edge_ids = utils.ensure_ids(selection.flatten())
         if properties is None:
-            Deprecate.warn("Returning ids with get/properties will be removed in 1.0.0."
-                           "Please use EdgePopulation.ids() instead.")
+            Deprecate.warn(
+                "Returning ids with get/properties is deprecated and will be removed in 1.0.0. "
+                "Please use EdgePopulation.ids instead."
+            )
             return edge_ids
 
         if utils.is_iterable(properties):
@@ -562,9 +588,9 @@ class EdgePopulation:
             if isinstance(first(result, None), CircuitEdgeId):
                 try:
                     result = [cid.id for cid in result if cid.population == self.name]
-                except AttributeError:
+                except AttributeError as e:
                     raise BluepySnapError("All values from a list must be of type int or "
-                                          "CircuitEdgeId.")
+                                          "CircuitEdgeId.") from e
         if sample is not None:
             if len(result) > 0:
                 result = np.random.choice(result, min(sample, len(result)), replace=False)
@@ -594,8 +620,10 @@ class EdgePopulation:
 
     def properties(self, edge_ids, properties):
         """Doc is overridden below."""
-        Deprecate.warn("EdgePopulation.properties function will be deprecated in 1.0.0. Please use "
-                       "EdgePopulation.get instead.")
+        Deprecate.warn(
+            "EdgePopulation.properties function is deprecated and will be removed in 1.0.0. "
+            "Please use EdgePopulation.get instead."
+        )
         return self.get(edge_ids, properties)
 
     properties.__doc__ = get.__doc__
@@ -613,10 +641,7 @@ class EdgePopulation:
         """
         assert side in ('afferent', 'efferent')
         assert kind in ('center', 'surface')
-        props = {
-            '{side}_{kind}_{p}'.format(side=side, kind=kind, p=p): p
-            for p in ['x', 'y', 'z']
-        }
+        props = {f'{side}_{kind}_{p}': p for p in ['x', 'y', 'z']}
         result = self.get(edge_ids, list(props))
         result.rename(columns=props, inplace=True)
         result.sort_index(axis=1, inplace=True)
