@@ -31,7 +31,7 @@ from bluepysnap import query
 from bluepysnap.network import NetworkObject
 from bluepysnap import utils
 from bluepysnap.exceptions import BluepySnapError
-from bluepysnap.sonata_constants import (DYNAMICS_PREFIX, Node, ConstContainer)
+from bluepysnap.sonata_constants import (DEFAULT_NODE_TYPE, DYNAMICS_PREFIX, Node, ConstContainer)
 from bluepysnap.circuit_ids import CircuitNodeId, CircuitNodeIds
 from bluepysnap._doctools import AbstractDocSubstitutionMeta
 
@@ -112,7 +112,7 @@ class Nodes(NetworkObject, metaclass=AbstractDocSubstitutionMeta,
         if isinstance(group, CircuitNodeIds):
             diff = np.setdiff1d(group.get_populations(unique=True), self.population_names)
             if diff.size != 0:
-                raise BluepySnapError("Population {} does not exist in the circuit.".format(diff))
+                raise BluepySnapError(f"Population {diff} does not exist in the circuit.")
 
         fun = lambda x: (x.ids(group, raise_missing_property=False), x.name)
         return self._get_ids_from_pop(fun, CircuitNodeIds, sample=sample, limit=limit)
@@ -156,7 +156,8 @@ class NodeStorage:
             NodeStorage: A NodeStorage object.
         """
         self._h5_filepath = config['nodes_file']
-        self._csv_filepath = config['node_types_file']
+        self._csv_filepath = config.get('node_types_file')
+        self._populations_config = config.get('populations', {})
         self._circuit = circuit
         self._populations = {}
 
@@ -188,7 +189,10 @@ class NodeStorage:
     def population(self, population_name):
         """Access the different populations from the storage."""
         if population_name not in self._populations:
-            self._populations[population_name] = NodePopulation(self, population_name)
+            population_config = self._populations_config.get(population_name)
+            self._populations[population_name] = NodePopulation(
+                self, population_name, population_config=population_config)
+
         return self._populations[population_name]
 
     def load_population_data(self, population):
@@ -227,15 +231,18 @@ class NodeStorage:
 class NodePopulation:
     """Node population access."""
 
-    def __init__(self, node_storage, population_name):
+    def __init__(self, node_storage, population_name, population_config=None):
         """Initializes a NodePopulation object from a NodeStorage and population name.
 
         Args:
             node_storage (NodeStorage): the node storage containing the node population
             population_name (str): the name of the node population
+            population_config (dict): the config for the population
+
         Returns:
             NodePopulation: A NodePopulation object.
         """
+        self._config = population_config or {}
         self._node_storage = node_storage
         self.name = population_name
 
@@ -258,6 +265,18 @@ class NodePopulation:
         """Node population size."""
         return self._population.size
 
+    @cached_property
+    def config(self):
+        """Population config dictionary combined with the components dictionary."""
+        components = deepcopy(self._node_storage.circuit.config.get('components', {}))
+        components.update(self._config)
+        return components
+
+    @property
+    def type(self):
+        """Population type."""
+        return self.config.get('type', DEFAULT_NODE_TYPE)
+
     @cached_property
     def _property_names(self):
         return set(self._population.attribute_names)
@@ -351,8 +370,7 @@ class NodePopulation:
     def _check_id(self, node_id):
         """Check that single node ID belongs to the circuit."""
         if node_id not in self._data.index:
-            raise BluepySnapError("node ID not found: {} in population"
-                                  " '{}'".format(node_id, self.name))
+            raise BluepySnapError(f"node ID not found: {node_id} in population '{self.name}'")
 
     def _check_ids(self, node_ids):
         """Check that node IDs belong to the circuit."""
@@ -366,18 +384,18 @@ class NodePopulation:
             max_id = max(node_ids)
             min_id = min(node_ids)
         if min_id < 0 or max_id >= self._data.index.shape[0]:
-            raise BluepySnapError("All node IDs must be >= 0 and < {} for population "
-                                  "'{}'".format(self._data.index.shape[0], self.name))
+            raise BluepySnapError(f"All node IDs must be >= 0 and < {self._data.index.shape[0]} "
+                                  f"for population '{self.name}'")
 
     def _check_property(self, prop):
         """Check if a property exists inside the dataset."""
         if prop not in self.property_names:
-            raise BluepySnapError("No such property: '%s'" % prop)
+            raise BluepySnapError(f"No such property: '{prop}'")
 
     def _get_node_set(self, node_set_name):
         """Returns the node set named 'node_set_name'."""
         if node_set_name not in self._node_sets:
-            raise BluepySnapError("Undefined node set: '%s'" % node_set_name)
+            raise BluepySnapError(f"Undefined node set: '{node_set_name}'")
         return self._node_sets[node_set_name]
 
     def _resolve_nodesets(self, queries):
@@ -494,9 +512,9 @@ class NodePopulation:
             if isinstance(first(result, None), CircuitNodeId):
                 try:
                     result = [cid.id for cid in result if cid.population == self.name]
-                except AttributeError:
+                except AttributeError as e:
                     raise BluepySnapError("All values from a list must be of type int or "
-                                          "CircuitNodeId.")
+                                          "CircuitNodeId.") from e
             self._check_ids(result)
             preserve_order = isinstance(group, Sequence)
 
@@ -527,18 +545,68 @@ class NodePopulation:
                 - ``mapping``: return the properties of nodes matching a properties filter.
                 - ``None``: return the properties of all nodes.
 
-            properties (list): If specified, return only the properties in the list.
+            properties (list|str|None): If specified, return only the properties in the list.
                 Otherwise return all properties.
 
         Returns:
             value/pandas.Series/pandas.DataFrame:
-                If single node ID is passed as ``group`` and single property as properties returns
-                a single value. If single node ID is passed as ``group`` and list as property
-                returns a pandas Series. Otherwise return a pandas DataFrame indexed by node IDs.
+                The type of the returned object depends on the type of the input parameters,
+                see the Examples for an explanation of the different cases.
 
         Notes:
             The NodePopulation.property_names function will give you all the usable properties
             for the `properties` argument.
+
+        Examples:
+            Considering a node population composed by 3 nodes (0, 1, 2) and 12 properties,
+            the following examples show the types of the returned objects.
+
+            - If ``group`` is a single node ID and ``properties`` a single property,
+              returns a single scalar value.
+
+                >>> result = my_node_population.get(group=0, properties=Cell.MTYPE)
+                >>> type(result)
+                str
+
+            - If ``group`` is a single node ID and ``properties`` a list or None,
+              returns a pandas Series indexed by the properties.
+
+                >>> result = my_node_population.get(group=0)
+                >>> type(result), result.shape
+                (pandas.core.series.Series, (12,))
+
+                >>> result = my_node_population.get(group=0, properties=[Cell.MTYPE])
+                >>> type(result), result.shape
+                (pandas.core.series.Series, (1,))
+
+            - If ``group`` is anything other than a single node ID, and ``properties`` is a single
+              property, returns a pandas Series indexed by node IDs.
+
+                >>> result = my_node_population.get(properties=Cell.MTYPE)
+                >>> type(result), result.shape
+                (pandas.core.series.Series, (3,))
+
+                >>> result = my_node_population.get(group=[0], properties=Cell.MTYPE)
+                >>> type(result), result.shape
+                (pandas.core.series.Series, (1,))
+
+            - In all the other cases, returns a pandas DataFrame indexed by node IDs.
+
+                >>> result = my_node_population.get()
+                >>> type(result), result.shape
+                (pandas.core.frame.DataFrame, (3, 12))
+
+                >>> result = my_node_population.get(group=[0])
+                >>> type(result), result.shape
+                (pandas.core.frame.DataFrame, (1, 12))
+
+                >>> result = my_node_population.get(properties=[Cell.MTYPE])
+                >>> type(result), result.shape
+                (pandas.core.frame.DataFrame, (3, 1))
+
+                >>> result = my_node_population.get(group=[0], properties=[Cell.MTYPE])
+                >>> type(result), result.shape
+                (pandas.core.frame.DataFrame, (1, 1))
         """
         result = self._data
         if properties is not None:
@@ -660,13 +728,13 @@ class NodePopulation:
     def morph(self):
         """Access to node morphologies."""
         from bluepysnap.morph import MorphHelper
-        return MorphHelper(
-            self._node_storage.circuit.config['components']['morphologies_dir'],
-            self
-        )
+
+        return MorphHelper(self.config.get('morphologies_dir'),
+                           self,
+                           alternate_morphologies=self.config.get('alternate_morphologies'))
 
     @cached_property
     def models(self):
         """Access to node neuron models."""
         from bluepysnap.neuron_models import NeuronModelsHelper
-        return NeuronModelsHelper(self._node_storage.circuit.config['components'], self)
+        return NeuronModelsHelper(self.config, self)
