@@ -54,8 +54,7 @@ def _collect_frame_reports(sim):
             from bluepysnap.frame_report import CompartmentReport
             cls = CompartmentReport
         else:
-            raise BluepySnapError(
-                "Report {}: format {} not yet supported.".format(name, report_type))
+            raise BluepySnapError(f"Report {name}: format {report_type} not yet supported.")
         res[name] = cls(sim, name)
     return res
 
