@@ -102,11 +102,11 @@ class PopulationSpikeReport:
         try:
             res = self._spike_population.get(node_ids=node_ids, tstart=t_start, tstop=t_stop)
         except SonataError as e:
-            raise BluepySnapError(e)
+            raise BluepySnapError(e) from e
 
         if not res:
             return pd.Series(data=[], index=pd.Index([], name="times"),
-                             name=series_name, dtype=np.float64)
+                             name=series_name, dtype=IDS_DTYPE)
 
         res = pd.DataFrame(data=res, columns=[series_name, "times"]).set_index("times")[series_name]
         if self._sorted_by != "by_time":
@@ -225,7 +225,7 @@ class SpikeReport:
         path = Path(self.config["output_dir"]) / self.config["log_file"]
         if not path.exists():
             raise BluepySnapError("Cannot find the log file for the spike report.")
-        yield open(str(path), "r")
+        yield path.open("r", encoding='utf-8')
 
     @cached_property
     def _spike_reader(self):
